==> encog-core-3.0.2-release.zip: encog-core-3.0.2/src/test/java/org/encog/neural/activation/TestActivationGaussian.java <==
/*
 * Encog(tm) Core Unit Tests v3.0 - Java Version
 * http://www.heatonresearch.com/encog/
 * http://code.google.com/p/encog-java/
 
 * Copyright 2008-2011 Heaton Research, Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *   
 * For more information on Heaton Research copyrights, licenses 
 * and trademarks visit:
 * http://www.heatonresearch.com/copyright
 */
package org.encog.neural.activation;

import junit.framework.TestCase;

import org.encog.engine.network.activation.ActivationGaussian;
import org.junit.Assert;
import org.junit.Test;

public class TestActivationGaussian extends TestCase {
	
	@Test
	public void testGaussian() throws Throwable
	{
		ActivationGaussian activation = new ActivationGaussian(0.0,0.5,1.0);
		Assert.assertTrue(activation.hasDerivative());
		
		ActivationGaussian clone = (ActivationGaussian)activation.clone();
		Assert.assertNotNull(clone);
		
		double[] input = { 0.0  };
		
		activation.activationFunction(input,0,input.length);
		
		Assert.assertEquals(0.5,input[0],0.1);
		
		input[0] = activation.derivativeFunction(input[0],input[0]);
		Assert.assertEquals(-33,(int)(input[0]*100),0.1);		
		
		
		
	}
}

==> encog-core-3.1.0-release.zip: encog-core-3.1.0/src/test/java/org/encog/neural/activation/TestActivationGaussian.java <==
/*
 * Encog(tm) Core v3.1 - Java Version
 * http://www.heatonresearch.com/encog/
 * http://code.google.com/p/encog-java/
 
 * Copyright 2008-2012 Heaton Research, Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *   
 * For more information on Heaton Research copyrights, licenses 
 * and trademarks visit:
 * http://www.heatonresearch.com/copyright
 */
package org.encog.neural.activation;

import junit.framework.TestCase;

import org.encog.engine.network.activation.ActivationGaussian;
import org.junit.Assert;
import org.junit.Test;

public class TestActivationGaussian extends TestCase {
	
	@Test
	public void testGaussian() throws Throwable
	{
		ActivationGaussian activation = new ActivationGaussian(0.0,1.0);
		Assert.assertFalse(!activation.hasDerivative());
		
		ActivationGaussian clone = (ActivationGaussian)activation.clone();
		Assert.assertNotNull(clone);
		
		double[] input = { 0.0  };
		
		activation.activationFunction(input,0,input.length);
		
		Assert.assertEquals(1.0,input[0],0.1);
		
		input[0] = activation.derivativeFunction(input[0],input[0]);
		Assert.assertEquals(0,(int)(input[0]*100),0.1);		
		
		
		
	}
}
